@@ -1,4 +1,3 @@
-use std::env;
 use std::path::Path;
 
 use crate::scripting;
@@ -24,14 +23,6 @@ pub fn get_rc_file() -> String {
 }
 
 pub fn load_rc_files(sh: &mut shell::Shell) {
-    // make "/usr/local/bin" as the first item in PATH
-    if let Ok(env_path) = env::var("PATH") {
-        if !env_path.contains("/usr/local/bin:") {
-            let env_path_new = format!("/usr/local/bin:{}", env_path);
-            env::set_var("PATH", &env_path_new);
-        }
-    }
-
     let rc_file = get_rc_file();
     if !Path::new(&rc_file).exists() {
         return;
